import { FC, useState } from "react";

export const AddTodoForm: FC<{
  onAdd: (todoName: string, project: string) => void;
  onClose: () => void;
  project: string;
}> = ({ onAdd, onClose, ...props }) => {
  const [todoName, setTodoName] = useState("");
  const [project, setProject] = useState(props.project);

  return (
    <form
      onSubmit={(e) => {
        e.preventDefault();
        onAdd(todoName, project);
        setTodoName("");
      }}
    >
      <div className="py-2 space-y-3">
        <div className="flex flex-col md:flex-row gap-4">
          <div className="todo-input-form md:flex-grow py-2 px-4 bg-gray-800 border border-gray-500 rounded-lg">
            <input
              type="text"
              placeholder="Todo name"
              className="text-sm w-full"
              autoFocus
              value={todoName}
              tabIndex={1}
              onChange={(e) => setTodoName(e.target.value)}
            />
          </div>
          <div className="todo-project py-2 px-4 bg-gray-700 border border-gray-500 rounded-lg ">
            <input
              type="text"
              placeholder="Project name"
              className="text-sm w-full placeholder-gray-400"
              value={project}
              tabIndex={2}
              onChange={(e) => setProject(e.target.value)}
            />
          </div>
        </div>
        <div className="space-x-2">
          <button
            type="submit"
            tabIndex={2}
            disabled={!todoName}
            className="base-button dark:bg-accent-500 disabled:bg-accent-800 active:bg-accent-400"
          >
            Add todo
          </button>
          <button
            tabIndex={3}
            type="button"
            className="base-button"
            onClick={onClose}
          >
            Cancel
          </button>
        </div>
      </div>
    </form>
  );
};
