import { useRouter } from "next/router";
import {
  useSelectTodo,
  useUpdateTodo,
} from "@src/presentation/hooks/socketHooks";
import { Todo } from "@src/core/entities/todo";
import { FC, useEffect, useState } from "react";
import { PageHeading } from "@src/components/common/headings/pageHeading";
import { TodoCheckmark } from "@src/components/todos/todoCheckmark";

interface EditTodoProps {
  todo: Todo;
  onCancel: () => void;
  onSave: (todo: Todo) => void;
}
const EditTodo: FC<EditTodoProps> = ({ todo, onCancel, onSave }) => {
  const [todoTitle, setTodoTitle] = useState(todo.title);

  return (
    <div className="space-y-4 flex-grow">
      <div className="bg-gray-900 rounded-lg">
        <input
          className="py-2 px-4"
          value={todoTitle}
          onChange={(e) => setTodoTitle(e.target.value)}
          type="text"
        />
      </div>
      <div className="space-x-4">
        <button
          className="base-button dark:bg-accent-500 disabled:bg-accent-800 active:bg-accent-400"
          onClick={() => {
            onSave({ ...todo, title: todoTitle });
          }}
        >
          Save
        </button>
        <button className="base-button" onClick={() => onCancel()}>
          Cancel
        </button>
      </div>
    </div>
  );
};

interface TodoDetailsProps {
  todo: Todo;
}

const TodoDetails: FC<TodoDetailsProps> = ({ todo }) => {
  const [updatedTodo, setUpdatedTodo] = useState(todo);
  const { updateTodo } = useUpdateTodo();
  const [editMode, setEditMode] = useState(false);

  useEffect(() => {
    updateTodo(updatedTodo);
  }, [updatedTodo]);

  return (
    <div className="bg-gray-800 rounded-xl p-8 shadow-lg space-y-4">
      <PageHeading title={updatedTodo.project || "Inbox"} />
      <div className="flex flex-row items-center gap-4">
        {editMode ? (
          <EditTodo
            todo={todo}
            onCancel={() => setEditMode(false)}
            onSave={(todo) => {
              setUpdatedTodo(todo);
              setEditMode(false);
            }}
          />
        ) : (
          <>
            <TodoCheckmark
              updateTodo={(t) => {
                setUpdatedTodo(t);
              }}
              todo={updatedTodo}
            />
            <h4 className="flex-grow" onClick={() => setEditMode(true)}>
              {updatedTodo.title}
            </h4>
          </>
        )}
      </div>
    </div>
  );
};

const TodoDetailsPage = () => {
  const router = useRouter();
  const { todoId } = router.query as { todoId: string };

  const { todo } = useSelectTodo(todoId);

  return (
    <main className="py-8 px-14 space-y-6">
      <section className="space-y-8 mx-auto max-w-4xl">
        {todo ? <TodoDetails todo={todo} /> : <div>Todo was not found</div>}
      </section>
    </main>
  );
};

export default TodoDetailsPage;
