import { useContext, useEffect } from "react";
import { SocketContext } from "@src/presentation/contexts/SocketContext";
import { StatusState, Todo } from "@src/core/entities/todo";

export const useSelectInboxTodos = () => {
  const socketContext = useContext(SocketContext);

  useEffect(() => {
    socketContext.getInboxTodos();
  }, []);

  return {
    loading: false,
    todos: socketContext.inboxTodos,
  };
};

export const useCreateTodo = () => {
  const socketContext = useContext(SocketContext);

  return {
    createTodo: (todoName: string, project: string) => {
      socketContext.createTodo(todoName, project);
    },
  };
};

export const useUpdateTodoState = () => {
  const socketContext = useContext(SocketContext);

  return {
    updateTodoState: (todoId: string, todoState: StatusState) => {
      socketContext.updateTodo(todoId, todoState);
    },
  };
};

export const useSelectTodo = (todoId: string): { todo: Todo | undefined } => {
  const socketContext = useContext(SocketContext);

  useEffect(() => {
    socketContext.getTodoById(todoId);
  }, []);

  return {
    todo: socketContext.todos.find((t) => t.id === todoId),
  };
};

export const useUpdateTodo = () => {
  const socketContext = useContext(SocketContext);

  return {
    updateTodo: (todo: Todo) => {
      socketContext.replaceTodo(todo);
    },
  };
};
